pub async fn get_for_users_and_course(
conn: &mut PgConnection,
user_ids: &[Uuid],
course: &Course,
) -> ModelResult<Vec<UserChapterLockingStatus>>Expand description
Returns all chapter locking statuses for the given users in a course.
pub async fn get_for_users_and_course(
conn: &mut PgConnection,
user_ids: &[Uuid],
course: &Course,
) -> ModelResult<Vec<UserChapterLockingStatus>>Returns all chapter locking statuses for the given users in a course.